function [aeig] = ntp(aalpha,bbeta,ggamma,N,P,kk,B,rho,mu)

%
% function [aeig] = ntp(N,P,kk,B,aalpha,bbeta,ggamma,rho,mu)
%  
% Compute the spectrum of NLS linearized around a 
% non-trivial phase solution,
% using the Jacobi elliptic function JacobiSN 
% The eigenvalue probelm is 
% M[u,v]' = omega[u,v]'
% or, multiplying through by phi^4,
% to generate the generalized eval problem
% M' [u,v]' = omega [C] [u,v]'
%
% Here we consider the generalized problem
%
% INPUT
% N is number of (positive) fourier modes for coefficients
% P determines the shift (and band structure)
% aalpha, bbeta, ggamma from
% i psi_t + alpha psi_xx + beta psi_yy + gamma psi^2 bar{psi} =0
% rho is scaler wave-number of transverse pert
% mu is the floquet shift in this interval 
%
% OUTPUT
% aeig = all eigenvalues 
%

pattern = 1;
mult = 1+pattern; % used to set optimal # of modes for 
               % and control # of off diagonal

% read in data
% to get aalpha,bbeta,ggamma,lambda,
% c,A,B,
% and L
% also get Q(-NP:NP),R(-NP:NP),and S(-NP:NP) coefficients from file
I = i;

params = load('./temp_p.dat');
k = params(1);
aalpha = params(2);
ggamma = params(3);
K = params(4);
L = params(5);
lambda = params(6);
c = params(7);
A = params(8);
B = params(9);

NP = ceil(mult*N/P)+1;
dat = load('./temp_F.dat');

if length(dat)<NP
	error('Need to extend the data files');
end

Q = ([(dat(NP:-1:2,1)) ; dat(1:NP,1)]); %fft(phi2)
R = ([(dat(NP:-1:2,2)) ; dat(1:NP,2)]); %fft(phi4)
S = ([(dat(NP:-1:2,3)) ; dat(1:NP,3)]); %fft(phi6)
T = ([-(dat(NP:-1:2,4)); dat(1:NP,4)])*I; %fft(phi phi_x)

% determine indices used in construction of matrices
cidx = find(mod([-mult*N:mult*N],P)==0); % row 1 column idx for diag insertion
didx = cidx - (mult*N+1);           % distance from main diag (which is 0)
qidx = didx/P + (NP);        % idx for Q modes  (Q0 = Q(NP))
ld = 2*N+1 - abs(didx);        % length of diagonal element
% build some vectors for n
nn = [-N:N];
Nmatrix = repmat(nn,2*N+1,1);
nn = nn(:);

startidx = 1;
store = [];

M11 = zeros(2*N+1); M22 = M11; 
M12 = M11; M21 = M11;
C0=M11; C1 = M11;
% load off diagonal entries
for k = 1:length(didx) % step through shifted entries
   % U equation  
   unit = ones(ld(k),1); %unit vector of proper diag vector length
   nnn = diag(Nmatrix,didx(k));
   partial_x = 2*I*nnn*pi/L/P+I*mu(j);
   M11 = M11 + ...
          diag(2*aalpha*c*T(qidx(k))*unit,didx(k))+...
          diag(-2*aalpha*c*Q(qidx(k))*partial_x,didx(k));
   M12 = M12 + ...
          diag((lambda+bbeta*rho(step)^2)*R(qidx(k))*unit,didx(k))+...
          diag(-1*ggamma*S(qidx(k))*unit,didx(k))+...
          diag(-1*aalpha*R(qidx(k))*(partial_x).^2,didx(k));
   % V equation shift entries
   M21 = M21 +...
          diag(-(lambda+bbeta*rho(step)^2)*R(qidx(k))*unit,didx(k))+...
          diag( 3*ggamma*S(qidx(k))*unit,didx(k))+...
          diag( 1*aalpha*R(qidx(k))*(partial_x).^2,didx(k));
   M22 = M22 + ...
          diag( 2*aalpha*c*T(qidx(k))*unit,didx(k))+...
          diag(-2*aalpha*c*Q(qidx(k))*partial_x,didx(k));
   C1 = C1+diag(R(qidx(k))*unit,didx(k)); 
end

% now add main diagonal 
M12 = M12 + aalpha*c^2*eye(2*N+1);
M21 = M21 - aalpha*c^2*eye(2*N+1);

% Build matrices: 
M = [ [M11 , M12] ; [M21 , M22]];
C = [ [C1 , C0  ] ; [C0  , C1 ]];

aeig = eig(M,C);
