function [phi2,phi4,phi6,phiphi_x] = power_phi(k,B,N,alph,gam);

% function [phi2,phi4,phi6,phiphi_x] = power_phi(k,B,N,alph,gam);
%
% Using Jacobi series solution for sn^2 
% we calculate the fourier coefficients for 
% phi^2 = alph/gam*(A sn^2(,k) + B)
% also phi^4 and phi^6 and phi*phi_x.
%
% For real valued elliptic fcns take 0 <= k < 1
%
% at k = 0, sn = sine

A = -2*k^2;
m = k^2;
mp = 1-m;
[K,E] = ellipke(m);   %matlab uses m
[Kp] = ellipke(mp);   %matlab uses m
q = exp(-pi*Kp/K);
I = i;

% first compute everything but the nonzero modes
% formally, 
% sn4 = 1/6/k^2*(sn2pp + (4*k^2+4)*sn2 - 2);
% but want series representation for this 
% so add the -2/6/k^2 to zero mode 

n = [1:N]; n = n(:);

% Jacobi's formula
sn2 = -pi^2/k^2/K^2 * (n.*q.^n./(1-q.^(2*n)));
%
sn2p = (I*n*pi/K) .* sn2;
sn2pp = (I*n*pi/K).^2 .* sn2;
sn4 = 1/6/k^2*(sn2pp + (4*k^2+4)*sn2);
sn4pp = (I*n*pi/K).^2 .* sn4;
sn6 = 1/20/k^2*( sn4pp + (16*k^2+16)*sn4-12*sn2);

% Compute zero modes
%
% Jacobi's formula
sn2_mode0 = (1-E/K)/k^2;

sn2p = [ 0 ; sn2p ];
sn2 = [ sn2_mode0 ; sn2];
sn4_mode0 = 1/6/k^2*((4*k^2+4)*sn2_mode0 - 2);
sn4 = [ sn4_mode0 ; sn4];
sn6_mode0 = 1/20/k^2*((16*k^2+16)*sn4_mode0-12*sn2_mode0);
sn6 = [ sn6_mode0 ; sn6];

% compute powers of phi without full zero mode contribution
phi2 = (alph/gam) * A*sn2;
phiphi_x = (alph/gam) * A*1/2*sn2p;
phi4 = (alph/gam)^2 * (A^2*sn4 + 2*A*B*sn2);
phi6 = (alph/gam).^3 * (A^3*sn6 + 3*A^2*B*sn4 + 3*A*B^2*sn2);

% add constant terms of expansion to zero modes
phi2(1) = phi2(1) + (alph/gam)*B;
phiphi_x(1) = 0;
phi4(1) = phi4(1) + (alph/gam)^2*B^2;
phi6(1) = phi6(1) + (alph/gam)^3*B^3;

